@@ -478,7 +478,7 @@ class GringoClasp(GringoClaspBase):
 	        count += 1
                 l = self._clasp.stdout.readline()
                 #print count,":",parser.parse(l)
-                printer.write(parser.parse(l))
+                printer.write(count, parser.parse(l))
                 
             if l.startswith('Models'):
                 # statistics start here
